# DateRangeFilter

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**from_date** | **datetime** |  | [optional] 
**from_date_license** | **datetime** |  | [optional] 
**period** | [**Period**](Period.md) |  | [optional] 
**time_frame** | [**Duration**](Duration.md) |  | [optional] 
**to_date** | **datetime** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


